@@ -29,7 +29,7 @@ cryptographic operations.
 
 use Catalyst::Runtime '5.70';
 
-use Catalyst qw/ConfigLoader Static::Simple/;
+use Catalyst qw/ConfigLoader Static::Simple -Debug/;
 
 =head1 CONFIGURATION
 
