@@ -258,7 +258,7 @@ sub formreq_remote {
     foreach my $part (keys(%$structure)){
     	$f->field($part, $structure->{$part});
     }
-    my $response = http_request_execute($f->press("Submit"), @args);
+    my $response = http_request_execute($f->press("Issue"), @args);
     return $response;
 }
 
@@ -273,7 +273,7 @@ throws an exception if the HTTP request isn't a success .
 sub formcall_remote {
     my $response = formreq_remote(@_);
     my $content = $response->content;
-    die sprintf("jsoncall_remote: failed with code %d\n%s\n",
+    die sprintf("formcall_remote: failed with code %d\n%s\n",
                 $response->code, $content) if ! $response->is_success;
     return $content if defined $content;
     die $content;
